km3pipe\.dataclasses\.HitSeries
===============================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: HitSeries

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HitSeries.__init__
      ~HitSeries.append_fields
      ~HitSeries.conv_from
      ~HitSeries.conv_to
      ~HitSeries.deserialise
      ~HitSeries.from_aanet
      ~HitSeries.from_arrays
      ~HitSeries.from_dict
      ~HitSeries.from_evt
      ~HitSeries.from_table
      ~HitSeries.next
      ~HitSeries.serialise
      ~HitSeries.sorted
   
   

   
   
   